

  .syntax unified
  .cpu cortex-m3
  .fpu softvfp
  .thumb

.global  g_pfnVectors
.global  IntDefaultHandler
.global __Vectors

/* start address for the initialization values of the .data section.
defined in linker script */
.word  _sidata
/* start address for the .data section. defined in linker script */
.word  _sdata
/* end address for the .data section. defined in linker script */
.word  _edata
/* start address for the .bss section. defined in linker script */
.word  _sbss
/* end address for the .bss section. defined in linker script */
.word  _ebss
/* stack used for SystemInit_ExtMemCtl; always internal RAM used */

  .section  .text.Reset_Handler
  .global Reset_Handler
  .global __stack_end__

Reset_Handler:
/* Setup stack pointer. Helpful for targets running in RAM without script file */
  ldr   r1, =__stack_end__
  msr   msp, r1

/* Copy the data segment initializers from flash to SRAM */
  movs  r1, #0
  b  LoopCopyDataInit

CopyDataInit:
  ldr  r3, =_sidata
  ldr  r3, [r3, r1]
  str  r3, [r0, r1]
  adds  r1, r1, #4

LoopCopyDataInit:
  ldr  r0, =_sdata
  ldr  r3, =_edata
  adds  r2, r0, r1
  cmp  r2, r3
  bcc  CopyDataInit
  ldr  r2, =_sbss
  b  LoopFillZerobss
/* Zero fill the bss segment. */
FillZerobss:
  movs  r3, #0
  str  r3, [r2], #4

LoopFillZerobss:
  ldr  r3, = _ebss
  cmp  r2, r3
  bcc  FillZerobss


/*FPU settings*/
 ldr     r0, =0xE000ED88
 ldr     r1,[r0]
 orr     r1,r1,#(0xF << 20)
 str     r1,[r0]

/* Call the clock system intitialization function.*/
/*  bl  SystemInit   */
/* Call static constructors */


/*    bl __libc_init_array */


/* Call the application's entry point.*/
  bl  main
  b   Reset_Handler
  
.size  Reset_Handler, .-Reset_Handler

/**
 * @brief  This is the code that gets called when the processor receives an
 *         unexpected interrupt.  This simply enters an infinite loop, preserving
 *         the system state for examination by a debugger.
 * @param  None
 * @retval None
*/
    .section  .text.IntDefaultHandler,"ax",%progbits
IntDefaultHandler:
Infinite_Loop:
  b  Infinite_Loop

  .size  IntDefaultHandler, .-IntDefaultHandler
/*
*******************************************************************************
*
* The minimal vector table for a Cortex M3. Note that the proper constructs
* must be placed on this to ensure that it ends up at physical address
* 0x0000.0000.
*
*******************************************************************************
*/
/*
    .extern Timer_0_Interrupt_Handler
*/
    .section  .isr_vector,"a",%progbits
    .type  g_pfnVectors, %object
    .size  g_pfnVectors, .-g_pfnVectors

g_pfnVectors:
__Vectors:
    .word  __stack_end__
    .word  Reset_Handler
    .word  NMI_Handler
    .word  HardFault_Handler
    .word  MemManage_Handler
    .word  BusFault_Handler
    .word  UsageFault_Handler
    .word  0
    .word  0
    .word  0
    .word  0
    .word  SVCall_Handler
    .word  DebugMon_Handler
    .word  0
    .word  PendSV_Handler
    .word  SysTick_Handler

    /* ADuCM33x specific peripheral interrupts */
	.word     IntDefaultHandler         /* Wake Up Timer              [ 0]   */
    .word     IntDefaultHandler         /* External Interrupt 0       [ 1]   */
    .word     IntDefaultHandler         /* External Interrupt 1       [ 2]   */
    .word     IntDefaultHandler         /* Watchdog timer             [ 3]   */
    .word     IntDefaultHandler         /* General purpose timer 0    [ 4]   */
    .word     IntDefaultHandler         /* ADC                        [ 5]   */
    .word     IntDefaultHandler         /* FLASH                      [ 6]   */
    .word     IntDefaultHandler         /* SPI                        [ 7]   */
    .word     IntDefaultHandler         /* LIN 0                      [ 8]   */
    .word     IntDefaultHandler         /* LIN 1                      [ 9]   */
    .word     IntDefaultHandler         /* LIN 2                 	  [10]   */
    .word     IntDefaultHandler         /* High Voltage Interface     [11]   */
    .word     IntDefaultHandler         /* CALOSC                     [12]   */
    .word     IntDefaultHandler         /* SRAM ECC                   [13]   */
    .word     IntDefaultHandler         /* 			  [14]   */
    .word     IntDefaultHandler         /* 			  [15]   */
    .word     IntDefaultHandler         /* 			  [16]   */
    .word     IntDefaultHandler         /*            [17]   */
    .word     IntDefaultHandler         /*            [18]   */
    .word     IntDefaultHandler         /*            [19]   */
    .word     IntDefaultHandler         /*            [20]   */
    .word     IntDefaultHandler         /*            [21]   */
    .word     IntDefaultHandler         /*            [22]   */
    .word     IntDefaultHandler         /*            [23]   */
    .word     IntDefaultHandler         /*            [24]   */
    .word     IntDefaultHandler         /*            [25]   */
    .word     IntDefaultHandler         /*            [26]   */
    .word     IntDefaultHandler         /*            [27]   */
    .word     IntDefaultHandler         /*            [28]   */
    .word     IntDefaultHandler         /*            [29]   */
    .word     IntDefaultHandler         /*            [30]   */
    .word     IntDefaultHandler         /*            [31]   */
  
/*******************************************************************************
*
* Provide weak aliases for each Exception handler to the IntDefaultHandler.
* As they are weak aliases, any function with the same name will override
* this definition.
*
*******************************************************************************/
   .weak      NMI_Handler
   .thumb_set NMI_Handler,IntDefaultHandler

   .weak      HardFault_Handler
   .thumb_set HardFault_Handler,IntDefaultHandler

   .weak      MemManage_Handler
   .thumb_set MemManage_Handler,IntDefaultHandler

   .weak      BusFault_Handler
   .thumb_set BusFault_Handler,IntDefaultHandler

   .weak      UsageFault_Handler
   .thumb_set UsageFault_Handler,IntDefaultHandler

   .weak      SVCall_Handler
   .thumb_set SVCall_Handler,IntDefaultHandler

   .weak      DebugMon_Handler
   .thumb_set DebugMon_Handler,IntDefaultHandler

   .weak      PendSV_Handler
   .thumb_set PendSV_Handler,IntDefaultHandler

   .weak      SysTick_Handler
   .thumb_set SysTick_Handler,IntDefaultHandler

/******************************************************************************/
